import tailwindcss from '@tailwindcss/vite'

export default defineNuxtConfig({

  modules: [
    '@pinia/nuxt',
    '@nuxt/eslint',
    '@nuxt/ui',
    '@nuxtjs/i18n',
    '@pinia/nuxt',
  ],
  devtools: { enabled: false },
  css: [
    '@/assets/main.css',
    'vue3-toastify/dist/index.css',
    '@/assets/toastify-custom.css',
  ],
  ui: {},
  compatibilityDate: '2024-11-01',
  vite: {
    plugins: [tailwindcss()],
    build: {
      sourcemap: false,
    },
    server: {
      allowedHosts: ['arina.ma-al.pl', 'marek.ma-al.pl'],
      watch: {
        ignored: ['**/backend/pb_data/**'],
      },
      hmr: {
        host: '127.0.0.1',
        clientPort: 3000, // useful if proxying
      },
    },
  },
  typescript: {
    tsConfig: {
      compilerOptions: {
        typeRoots: ['./types', './node_modules/@types'],
      },
      include: ['./types'],
    },
  },

  i18n: {
    locales: [
      { code: 'pl', name: 'Polski', icon: 'circle-flags:pl' },
      { code: 'en', name: 'English', icon: 'circle-flags:gb' },
      { code: 'cs', name: 'Čeština', icon: 'circle-flags:cz' },
    ],
    lazy: true,
    defaultLocale: 'en',
    strategy: 'prefix',
    bundle: {
      optimizeTranslationDirective: false,
    },
  },
  icon: {
    localApiEndpoint: '/___nuxt_icon',
  },
})
